workload

package
v1.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 23, 2025 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package workload generates cache workload patterns.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateZipf

func GenerateZipf(n, keySpace int, theta float64, seed uint64) []string

GenerateZipf generates a Zipfian distribution of keys as strings ("key-X").

func GenerateZipfInt

func GenerateZipfInt(n, keySpace int, theta float64, seed uint64) []int

GenerateZipfInt generates a Zipfian distribution of keys as integers.

Types

This section is empty.

Jump to